@@ -1,3 +1,4 @@
+# $Id: NumEntry.pm,v 2.4 2003/01/13 23:06:40 eserte Exp $
 
 package Tk::NumEntry;
 
@@ -8,7 +9,7 @@ use strict;
 
 use vars qw(@ISA $VERSION);
 @ISA = qw(Tk::Derived Tk::Frame);
-$VERSION = '1.06';
+$VERSION = sprintf("%d.%02d", q$Revision: 2.4 $ =~ /(\d+)\.(\d+)/);
 
 Construct Tk::Widget 'NumEntry';
 
@@ -24,35 +25,39 @@ sub Populate {
 
     my $orient = delete $args->{-orient} || "vertical";
 
-    my $e = $f->Component( NumEntryPlain => 'entry',
+    my $readonly = delete $args->{-readonly};
+
+    my $e = $f->Component( $f->NumEntryPlainWidget => 'entry',
         -borderwidth        => 0,
         -highlightthickness => 0,
-	-parent             => $f,
     );
+    if ($readonly) {
+	$e->bindtags([]);
+    }
 
-    my $binc = $f->Component( FireButton => 'inc',
-	-bitmap		    => ($orient =~ /^vert/
-				? $Tk::FireButton::INCBITMAP
-				: $Tk::FireButton::HORIZINCBITMAP
-			       ),
-#	-command	    => sub { $e->incdec(1) },
-	-command	    => sub { $f->incdec(1) },
+    my $binc = $f->Component( $f->IncFireButtonWidget() => 'inc',
+	-command	    => sub { $e->incdec($e->cget(-increment)) },
 	-takefocus	    => 0,
 	-highlightthickness => 0,
 	-anchor             => 'center',
     );
+    $binc->configure(-bitmap => ($orient =~ /^vert/
+				 ? $binc->INCBITMAP
+				 : $binc->HORIZINCBITMAP
+				)
+		    );
 
-    my $bdec = $f->Component( FireButton => 'dec',
-	-bitmap		    => ($orient =~ /^vert/
-				? $Tk::FireButton::DECBITMAP
-				: $Tk::FireButton::HORIZDECBITMAP
-			       ),
-#	-command	    => sub { $e->incdec(-1) },
-	-command	    => sub { $f->incdec(-1) },
+    my $bdec = $f->Component( $f->DecFireButtonWidget() => 'dec',
+	-command	    => sub { $e->incdec(- $e->cget(-increment)) },
 	-takefocus	    => 0,
 	-highlightthickness => 0,
 	-anchor             => 'center',
     );
+    $bdec->configure(-bitmap => ($orient =~ /^vert/
+				 ? $bdec->DECBITMAP
+				 : $bdec->HORIZDECBITMAP
+				)
+		    );
 
     $f->gridColumnconfigure(0, -weight => 1);
     $f->gridColumnconfigure(1, -weight => 0);
@@ -96,6 +101,11 @@ sub Populate {
     $f;
 }
 
+sub NumEntryPlainWidget { "NumEntryPlain"         }
+sub FireButtonWidget    { "FireButton"            }
+sub IncFireButtonWidget { shift->FireButtonWidget }
+sub DecFireButtonWidget { shift->FireButtonWidget }
+
 sub buttons {
     my $f = shift;
     my $var = \$f->{Configure}{'-buttons'};
@@ -139,11 +149,14 @@ following options
 
 =head1 STANDARD OPTIONS
 
-Besides the standard options of the L<Button|Tk::Button> widget
+Besides the standard options of the L<Entry|Tk::Entry> widget
 NumEntry supports:
 
 B<-orient> B<-repeatdelay> B<-repeatinterval>
 
+The B<-orient> option specifies the packing order of the increment and
+decrement buttons. This option can only be set at creation time.
+
 =head1 WIDGET-SPECIFIC OPTIONS
 
 =over 4
@@ -158,13 +171,31 @@ B<-orient> B<-repeatdelay> B<-repeatinterval>
 
 Boolean that defines if the inc and dec buttons are visible.
 
+
+=item Switch:           B<-readonly>
+
+=item Fallback:		B<0>
+
+If B<-readonly> is set to a true value, then the value can only be
+changed by pressing the increment/decrement buttons. This option can
+only be set at creation time.
+
 =back
 
+=head1 WIDGET METHODS
+
+Subclasses of NumEntry may override the following methods to use
+different widgets for the composition of the NumEntry. These are:
+NumEntryPlainWidget (usually C<NumEntryPlain>), FireButtonWidget
+(usually C<FireButton>, IncFireButtonWidget and DecFireButtonWidget.
+FireButtonWidget is used if IncFireButtonWidget or DecFireButtonWidget
+are not defined.
 
 =head1 AUTHOR
 
 Graham Barr <F<gbarr@pobox.com>>
 
+Current maintainer is Slaven Rezic <F<slaven.rezic@berlin.de>>.
 
 =head1 ACKNOWLEDGEMENTS
 
